Project Recurring Expense
=========================

.. autoclass:: moco_wrapper.models.ProjectRecurringExpense
    :members:


.. autoclass:: moco_wrapper.models.project_recurring_expense.ProjectRecurringExpensePeriod
   :members:
   :undoc-members:
